@@ -1,4 +1,7 @@
 package Storm::LiveObjects::Scope;
+{
+  $Storm::LiveObjects::Scope::VERSION = '0.18';
+}
 
 use Moose;
 use namespace::clean -except => 'meta';
@@ -33,8 +36,8 @@ sub DEMOLISH {
 
     if ( my $lo = $self->live_objects ) {
         $self->parent ?
-        $lo->_set_current_scope ( $self ) :
-        $lo->_clear_current_scope;
+        $lo->set_current_scope ( $self->parent ) :
+        $lo->clear_current_scope;
     }
 }
 
