@@ -1,9 +1,11 @@
 package Storm::Meta::Column;
+{
+  $Storm::Meta::Column::VERSION = '0.18';
+}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 use MooseX::StrictConstructor;
-use MooseX::Method::Signatures;
 
 use MooseX::Types::Moose qw( Bool Str Undef );
 
@@ -25,10 +27,9 @@ has 'auto_increment' => (
 );
 
 
-method sql {
-    $self->table ?
-    $self->table->name . '.' . $self->name :
-    $self->name;
+sub sql  {
+    my ( $self, $table ) = @_;
+    $table ? $table->name . '.' . $self->name :  $self->name;
 }
 
 no Moose;
