@@ -1,21 +1,25 @@
 package Storm::Query::Delete;
+{
+  $Storm::Query::Delete::VERSION = '0.18';
+}
 
 use Moose;
 use MooseX::StrictConstructor;
 use MooseX::SemiAffordanceAccessor;
-use MooseX::Method::Signatures;
 
 with 'Storm::Role::Query';
 with 'Storm::Role::Query::IsExecutable';
 
-method _sql ( ) {
-    my $table = $self->class->meta->table->sql;
+sub _sql {
+    my ( $self ) = @_;
+    my $table = $self->class->meta->storm_table->sql;
     my $column = $self->class->meta->primary_key->column->sql;
     return  qq[DELETE FROM $table WHERE $column = ?];
 }
 
 
-method delete ( @objects ) {
+sub delete  {
+    my ( $self, @objects ) = @_;
     my $sth     = $self->_sth;
     
     for my $o (@objects) {
