@@ -1,9 +1,11 @@
 package Storm::Role::Query;
+{
+  $Storm::Role::Query::VERSION = '0.18';
+}
 use Moose::Role;
 
 use Storm::Types qw( Storm );
 use MooseX::Types::Moose qw( ClassName );
-use MooseX::Method::Signatures;
 
 has 'orm' => (
     is  => 'ro',
@@ -17,21 +19,22 @@ has 'class' => (
     required => 1,
 );
 
-sub BUILDARGS {
+around BUILDARGS => sub {
+    my $orig = shift;
     my $class = shift;
     
     # parse arguments
-    if (@_ == 2 ) {
-        return { orm => $_[0], class => $_[1] }
+    if (@_ >= 2 ) {
+        return $class->$orig( orm => shift, class => shift, @_ );
     }
     # otherwise pass upwords to deal with
     else {
-        return __PACKAGE__->SUPER::BUILDARGS(@_);
+        return $class->$orig( @_ );
     }
-}
+};
 
-method dbh ( ) {
-    $self->orm->source->dbh;
+sub dbh  {
+    $_[0]->orm->source->dbh;
 }
 
 no Moose::Role;
