@@ -1,7 +1,9 @@
 package Storm::Role::Query::HasAttributeOrder;
+{
+  $Storm::Role::Query::HasAttributeOrder::VERSION = '0.18';
+}
 
 use Moose::Role;
-use MooseX::Method::Signatures;
 use MooseX::Types::Moose qw( ArrayRef );
 
 
@@ -14,16 +16,17 @@ has 'attribute_order' => (
     }
 );
 
-method _build_attribute_order {
+sub _build_attribute_order {
+    my ( $self ) = @_;
     my $meta = $self->class->meta;
     
     # make sure the primary key is the first entry in the order
     my @order = ( $self->class->meta->primary_key );
     
     # create the attribute order
-    for my $attribute ( map { $meta->get_attribute($_) } $meta->get_attribute_list ) {
+    for my $attribute ( $meta->get_all_attributes ) {
         next if $attribute->name eq $order[0]->name; # skip if this is the primary key
-        next if ! $attribute->column;
+        next if ! $attribute->can('column') || ! $attribute->column;
         push @order, $attribute;
     }
 
