@@ -1,4 +1,7 @@
 package Storm::Types;
+{
+  $Storm::Types::VERSION = '0.18';
+}
 use MooseX::Types -declare => [qw(
     DBIStatementHandle
     MooseAttribute
@@ -11,6 +14,7 @@ use MooseX::Types -declare => [qw(
     StormDeleteQuery
     StormEnabledClassName
     StormEnabledObject
+    StormForeignKeyConstraintValue
     StormInsertQuery
     StormLiveObjects
     StormLiveObjectScope
@@ -135,6 +139,9 @@ subtype StormSQLWhereBoolean,
     as Str,
     where { return $_ =~ /^(?:and|not|or|xor)$/ };
 
+subtype StormForeignKeyConstraintValue,
+    as Str,
+    where { return $_ =~ /^(?:CASCADE|RESTRICT|NO ACTION|SET NULL)$/i};
 
 class_type StormUpdateQuery,
     { class => 'Storm::Query::Update' };
